@@ -36,10 +36,10 @@ class EqlClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes an async EQL search by ID. If the search is still running, the search
-        request will be cancelled. Otherwise, the saved search results are deleted.
+        Delete an async EQL search. Delete an async EQL search or a stored synchronous
+        EQL search. The API also deletes results for the search.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/eql-search-api.html>`_
 
         :param id: Identifier for the search to delete. A search ID is provided in the
             EQL search API's response for an async search. A search ID is also provided
@@ -76,16 +76,17 @@ class EqlClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        keep_alive: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         wait_for_completion_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+            t.Union[str, t.Literal[-1], t.Literal[0]]
         ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns async results from previously executed Event Query Language (EQL) search
+        Get async EQL search results. Get the current status and available results for
+        an async EQL search or a stored synchronous EQL search.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/get-async-eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-async-eql-search-api.html>`_
 
         :param id: Identifier for the search.
         :param keep_alive: Period for which the search and its results are stored on
@@ -133,10 +134,10 @@ class EqlClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns the status of a previously submitted async or stored Event Query Language
-        (EQL) search
+        Get the async EQL status. Get the current status for an async EQL search or a
+        stored synchronous EQL search without returning results.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/get-async-eql-status-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-async-eql-status-api.html>`_
 
         :param id: Identifier for the search.
         """
@@ -193,9 +194,9 @@ class EqlClient(NamespacedClient):
         expand_wildcards: t.Optional[
             t.Union[
                 t.Sequence[
-                    t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str]
+                    t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]]
                 ],
-                t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str],
+                t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]],
             ]
         ] = None,
         fetch_size: t.Optional[int] = None,
@@ -208,23 +209,25 @@ class EqlClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         ignore_unavailable: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        keep_alive: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         keep_on_completion: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        result_position: t.Optional[t.Union["t.Literal['head', 'tail']", str]] = None,
+        result_position: t.Optional[t.Union[str, t.Literal["head", "tail"]]] = None,
         runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         size: t.Optional[int] = None,
         tiebreaker_field: t.Optional[str] = None,
         timestamp_field: t.Optional[str] = None,
         wait_for_completion_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+            t.Union[str, t.Literal[-1], t.Literal[0]]
         ] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns results matching a query expressed in Event Query Language (EQL)
+        Get EQL search results. Returns search results for an Event Query Language (EQL)
+        query. EQL assumes each document in a data stream or index corresponds to an
+        event.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/eql-search-api.html>`_
 
         :param index: The name of the index to scope the operation
         :param query: EQL query you wish to run.
